/**
* @version $Id: general_rtl.css 10387 2008-06-03 10:59:16Z pasamio $
* @copyright Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
* @license GNU/GPL, see LICENSE.php
* Joomla! is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

/**
 * Joomla! 1.5 Admin template main RTL css file
 *
 * @author		Mati Kochen
 * @package		Joomla
 * @since		1.5
 * @version     1.0
 */

/* -- General styles ------------------------------ */

body{
	direction: rtl;
}

#border-top.h_green div div{
	background-image: url(../images/h_green/j_header_left_rtl.png);
}

#border-top.h_green div{
	background-image: url(../images/h_green/j_header_right_rtl.png);
}

.button1 { background: url(../images/j_button1_right.png) 100% 0 no-repeat; margin-left: 5px; padding-right: 10px; white-space: nowrap; padding-left: 0px; }
.button1 .next { background: url(../images/j_button1_prev.png) no-repeat; }
.button1 a { padding: 0 6px 0 30px; }

.button1,
.button1 div{
	float: left;
}

.button2-left a, .button2-left span {
	padding:0pt 6px 0pt 24px;
}

.button2-left {
	background:transparent url(../images/j_button2_right.png) no-repeat scroll 100%;
	float: right;
}

.button2-left .end{
	background:	transparent url(../images/j_button2_first.png) no-repeat scroll 0% 0;
}

.button2-left.off .end{
	background:	transparent url(../images/j_button2_first_off.png) no-repeat scroll 0% 0;
}

.button2-left .next{
	background:	transparent url(../images/j_button2_prev.png) no-repeat scroll 0% 0;
}

.button2-left.off .next{
	background:	transparent url(../images/j_button2_prev_off.png) no-repeat scroll 0% 0;
}

.button2-left .page,
.button2-left .blank {
	background: url(../images/j_button2_left_cap.png) 0 no-repeat;
}

.button2-right a, .button2-right span {
	padding:0pt 24px 0pt 6px;
}

.button2-left .image {
	background:transparent url(../images/j_button2_image_rtl.png) no-repeat scroll 0% 0pt;
}

.button2-left .pagebreak {
	background:transparent url(../images/j_button2_pagebreak_rtl.png) no-repeat scroll 0% 0pt;
}

.button2-left .readmore {
	background:transparent url(../images/j_button2_readmore_rtl.png) no-repeat scroll 0% 0pt;
}

.button2-right {
	background:transparent url(../images/j_button2_left.png) no-repeat scroll 0% 0pt;
	float: right;
}

.button2-right .prev {
	background:transparent url(../images/j_button2_next.png) no-repeat scroll 100%;
}

.button2-right.off .prev {
	background:transparent url(../images/j_button2_next_off.png) no-repeat scroll 100%;
}

.button2-right .start {
	background:transparent url(../images/j_button2_last.png) no-repeat scroll 100%;
}

.button2-right.off .start {
	background:transparent url(../images/j_button2_last_off.png) no-repeat scroll 100%;
}


#border-top .version{
	float: left;
	padding: 25px 0 0 5px;
}

#border-top .title{
	padding-right: 180px;
	padding-left: 0px;
}

#module-status {
	float:left;
}

#module-status span{
	padding: 4px 22px 0pt 10px;
}

#module-status .legacy-mode 		  { background-position: right 5px; }
#module-status .preview 			  { background-position: right 3px; }
#module-status .unread-messages,
#module-status .no-unread-messages { background-position: right 3px; }
#module-status .loggedin-users     { background-position: right 3px; }
#module-status .logout             { background-position: right 3px; }

table.adminform td{
	text-align: right;
}

#cpanel div.icon{
	margin-right: 0px;
	margin-left: 5px;
}

.jpane-toggler span,
.jpane-toggler-down span {
	background-position: right;
	padding-right: 20px;
	padding-left: 0px;
}

.jpane-toggler span{ background-image: url(../images/j_arrow_left.png); }

div.toolbar {
	float:left;
	padding:0pt;
	text-align:left;
}

div.header {
	margin-right:10px;
	margin-left:0px;
	padding-right:55px;
	padding-left:0px;
}

.header{ background-position: right; }

table.adminlist tbody tr{
	text-align: right;
}

table.adminform th{
	text-align: right;
	padding: 6px 4px 4px 2px;
}

fieldset {
	text-align:right;
}

table.adminform td.filter{
	text-align: right;
}

table.adminform td.helpMenu{
	text-align: left;
}

table.adminlist .pagination{
	display: -moz-box;
}

.pagination div.limit{
	float: right;
	margin: 0 0 0 10px;
}

.button2-left .page a, .button2-right .page a, .button2-left .page span, .button2-right .page span, .button2-left .blank a, .button2-right .blank a, .button2-left .blank span, .button2-right .blank span{
	float: right;
}

div.col{
	float: right;
}

#system-message dd.message ul {
	background-position: 99% center;
}

#system-message dd {
	text-indent:35px;
}

/* debug */
#system-debug ol,
#system-debug ul{
	direction: ltr;
}